pub struct CatalogRelationship {
pub partner: Partner,
pub external_catalog_managed: bool,
}Expand description
Relationship between a partner product line and whether an external vendor manages the catalog facts.
Fields
partner: PartnerSource-derived partner carried by this retail contract.
external_catalog_managed: boolSource-derived external catalog managed carried by this retail contract.